pub fn render_file_inferred_with_context_and_options(
path: impl AsRef<Path>,
rule_name: &str,
context: RenderContext,
options: RenderOptions,
) -> Result<String, ConfigError>Expand description
Renders one rule from a configuration file with initial context and render options, inferring formatted structured JSON for object-valued rules.