pub fn render_file_structured(
path: impl AsRef<Path>,
rule_name: &str,
) -> Result<CopperlaceValue, ConfigError>Expand description
Renders one object-valued rule from a configuration file as a structured value.
pub fn render_file_structured(
path: impl AsRef<Path>,
rule_name: &str,
) -> Result<CopperlaceValue, ConfigError>Renders one object-valued rule from a configuration file as a structured value.