pub fn render_file_with_context(
path: impl AsRef<Path>,
rule_name: &str,
context: RenderContext,
) -> Result<String, ConfigError>Expand description
Renders one rule from a configuration file with initial context.
pub fn render_file_with_context(
path: impl AsRef<Path>,
rule_name: &str,
context: RenderContext,
) -> Result<String, ConfigError>Renders one rule from a configuration file with initial context.