pub fn render_str_structured(
config: &str,
rule_name: &str,
) -> Result<CopperlaceValue, ConfigError>Expand description
Renders one object-valued rule from a configuration string as a structured value.
pub fn render_str_structured(
config: &str,
rule_name: &str,
) -> Result<CopperlaceValue, ConfigError>Renders one object-valued rule from a configuration string as a structured value.