pub fn render_str_with_context(
config: &str,
rule_name: &str,
context: RenderContext,
) -> Result<String, ConfigError>Expand description
Renders one rule from a configuration string with initial context.
pub fn render_str_with_context(
config: &str,
rule_name: &str,
context: RenderContext,
) -> Result<String, ConfigError>Renders one rule from a configuration string with initial context.