copperlace_ruleset_free

Function copperlace_ruleset_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn copperlace_ruleset_free( handle: *mut CopperlaceRuleSet, )
Releases a ruleset handle returned by the C ABI.

Passing null is allowed and has no effect.

Safety

handle must be null or a handle previously returned by Copperlace that has not already been freed. After this call, the handle must not be used again.