copperlace_string_free

Function copperlace_string_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn copperlace_string_free(value: *mut c_char)
Releases a string returned by the C ABI.

Passing null is allowed and has no effect.

Safety

value must be null or a string pointer previously returned by Copperlace that has not already been freed. After this call, the pointer must not be used again.