pub fn render_config_rule_with_context(
config: Value,
rule_name: &str,
context: RenderContext,
) -> Result<String, RenderError>Expand description
Compiles a parsed configuration root value and renders one rule with initial context.
pub fn render_config_rule_with_context(
config: Value,
rule_name: &str,
context: RenderContext,
) -> Result<String, RenderError>Compiles a parsed configuration root value and renders one rule with initial context.