pub struct UnsupportedValueNode { /* private fields */ }Expand description
Placeholder node for config value types that are not renderable yet.
Object values currently compile to this node unless they are the special
top-level context object handled by RuleSet::from_config. Rendering this
node returns RenderError::UnsupportedValue.
Implementations