pub struct VariableNode { /* private fields */ }Expand description
Looks up a previously bound variable in the current render context.
This node is useful when a template should require a value that was already
bound by a BindNode. In the current parser, normal {name} expressions use
RuleCallNode instead, because they can mean either a bound variable or a
named rule.
Implementations