#[unsafe(no_mangle)]pub unsafe extern "C" fn copperlace_processor_result_set_error(
result: *mut CopperlaceProcessorResult,
message: *const c_char,
) -> c_intExpand description
Sets the error for a custom processor callback result.
Safety
result must be the valid result handle passed to the active processor
callback. message must point to a valid NUL-terminated UTF-8 string.