#[unsafe(no_mangle)]pub unsafe extern "C" fn copperlace_processor_result_set_output(
result: *mut CopperlaceProcessorResult,
value: *const c_char,
) -> c_intExpand description
Sets the output for a custom processor callback result.
Safety
result must be the valid result handle passed to the active processor
callback. value must point to a valid NUL-terminated UTF-8 string.