pub struct BindNode { /* private fields */ }Expand description
Binds the output of a child node into the render context without emitting it.
This is the node generated for {% alias:rule %} statements. If alias is
not already bound, it renders rule and stores the result under alias. It
also supports {% alias:=rule %} statements, which always render rule and
overwrite alias. Binding statements always return an empty string so later
{alias} references reuse the generated value.
Implementations